@@ -97,41 +97,9 @@ const WorkflowComponent = ({ className }: IWorkflowComponent): JSX.Element => {
       setWorkflowParams(rest);
       return;
     }
-    if (['file-path', 'directory-path', 'path'].includes(format)) {
-      let fmt;
-      switch (format) {
-        case 'file-path':
-          fmt = 'file';
-          break;
-        case 'directory-path':
-          fmt = 'directory';
-          break;
-        default:
-          fmt = 'path';
-      }
-      validatePath(id, value, fmt);
-      return;
-    }
     setWorkflowParams({ ...workflowParams, [id]: value });
   };
 
-  const validatePath = async (id: string, path: string, format = 'file') => {
-    const encodedPath = encodeURIComponent(path);
-    const data = await requestAPI<any>(`${format}/${encodedPath}`, {
-      method: 'GET'
-    });
-    if (!data.exists) {
-      setWorkflowParamsErrors({
-        ...workflowParamsErrors,
-        [id]: [data.error]
-      });
-      setWorkflowParamsValid(false);
-      return;
-    }
-    setWorkflowParamsErrors({ ...workflowParamsErrors, [id]: [] });
-    setWorkflowParams({ ...workflowParams, [id]: path });
-  };
-
   useEffect(() => {
     if (workflowData) {
       const { valid, errors } = validateSchema(
@@ -171,8 +139,10 @@ const WorkflowComponent = ({ className }: IWorkflowComponent): JSX.Element => {
         {/* Workflow header */}
         <div className="workflow-section workflow-header">
           <h1>Workflow: {params.name}</h1>
-          <div className="workflow-details">
+          <div className="workflow-description">
             <div>{workflowData.desc}</div>
+          </div>
+          <div className="workflow-details">
             <div>Version {workflowData.defaults.wfversion}</div>
           </div>
         </div>
@@ -228,7 +198,7 @@ const StyledWorkflowComponent = styled(WorkflowComponent)`
   background-color: #f6f6f6;
 
   .workflow-container {
-    padding: 50px 0 100px 0 !important;
+    padding: 0 0 100px 0 !important;
   }
 
   .workflow-section {
@@ -247,15 +217,41 @@ const StyledWorkflowComponent = styled(WorkflowComponent)`
     padding-bottom: 15px;
   }
 
-  .workflow-details div {
-    color: #333;
-    font-weight: normal;
+  .workflow-header {
+    width: 100%;
+    margin: 0 auto 50px auto;
+    max-width: 100%;
+    box-shadow: none;
+    padding: 75px 0;
+    text-align: center;
+  }
+
+  .workflow-description div {
+    letter-spacing: 0em;
     font-size: 14px;
+    text-transform: none;
+    padding-bottom: 15px;
+    max-width: 700px;
+    line-height: 1.4em;
+    text-align: center;
+    margin: 0 auto;
+    color: #a0a0a0;
+  }
+
+  .workflow-details div {
+    /* color: #333;
+    font-weight: normal;
+    font-size: 14px; */
     padding-bottom: 5px;
+    color: #a0a0a0;
+    text-transform: uppercase;
+    font-size: 11px;
+    line-height: 1em;
+    letter-spacing: 0.05em;
   }
 
   .workflow-parameter-sections .workflow-section-contents > ul > li {
-    background-color: #f6f6f6;
+    background-color: #fafafa;
     padding: 15px;
     margin: 0 0 15px 0;
     border-radius: 4px;
